/*
LdapCheck.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;

import androidx.annotation.Nullable;
import androidx.annotation.NonNull;

/**
* Enum describing errors in LDAP parameters. <br/>
* <br/>
*/
public enum LdapCheck {
    /**
    * No error. <br/>
    * <br/>
    */
    Ok(0),

    /**
    * Server field is empty. <br/>
    * <br/>
    */
    ServerEmpty(1),

    /**
    * The server is not an url. <br/>
    * <br/>
    */
    ServerNotUrl(2),

    /**
    * The server doesn't contain a scheme. <br/>
    * <br/>
    */
    ServerNoScheme(4),

    /**
    * The server is not a LDAP scheme. <br/>
    * <br/>
    */
    ServerNotLdap(8),

    /**
    * LDAP over SSL is non-standardized and deprecated: ldaps has been specified. <br/>
    * <br/>
    */
    ServerLdaps(16),

    /**
    * Base Object has been specified. <br/>
    * <br/>
    */
    BaseObjectEmpty(32),

    /**
    * Some required fields are missing. <br/>
    * <br/>
    */
    MissingFields(64);

    protected final int mValue;

    private LdapCheck (int value) {
        mValue = value;
    }

    static public LdapCheck fromInt(int value) throws RuntimeException {
        switch(value) {
        case 0: return Ok;
        case 1: return ServerEmpty;
        case 2: return ServerNotUrl;
        case 4: return ServerNoScheme;
        case 8: return ServerNotLdap;
        case 16: return ServerLdaps;
        case 32: return BaseObjectEmpty;
        case 64: return MissingFields;
        default:
            throw new RuntimeException("Unhandled enum value " + value + " for LdapCheck");
        }
    }

    public int toInt() {
        return mValue;
    }
}
